==> dotup_flutter_simulator-3.0.1.tar.gz: lib/src/menu/menu_bar_vertical.dart <==
import 'package:dotup_flutter_widgets/dotup_flutter_widgets.dart';
import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';

import '../constants.dart';
import '../device/device_changed.dart';
import '../device/device_descriptor.dart';
import '../device_popup_menu_button.dart';
import '../simulator/simulator_controller.dart';
import '../helper/simulator_logo.dart';

class MenuBarVertical extends StatelessWidget {
  const MenuBarVertical({
    Key? key,
    required this.controller,
  }) : super(key: key);

  final SimulatorController controller;

  @override
  Widget build(BuildContext context) {
    final settings = controller.settings;
    final devices = controller.currentPlatform == TargetPlatform.android ? settings.androidDevices : settings.iosDevices;

    DeviceDescriptor device = controller.currentDevice;

    final portraitColor = controller.orientation == Orientation.portrait ? Colors.white : Colors.white24;
    final landscapeColor = controller.orientation == Orientation.landscape ? Colors.white : Colors.white24;

    final iosColor = controller.currentPlatform == TargetPlatform.iOS ? Colors.white : Colors.white24;
    final androidColor = controller.currentPlatform == TargetPlatform.android ? Colors.white : Colors.white24;
    final _showDeviceInfo = controller.realMediaQuery.size.height > 500;
    final _showDeviceSlider = controller.realMediaQuery.size.height > 700;

    bool overflowX = device.size.width > controller.realMediaQuery.size.width - SETTINGS_HEIGHT;
    bool overflowY = device.size.height > controller.realMediaQuery.size.height;

    return Material(
      child: Container(
        width: SETTINGS_HEIGHT,
        // height: 500,
        color: Colors.black,
        padding: EdgeInsets.all(8),
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.stretch,
          mainAxisSize: MainAxisSize.max,
          children: <Widget>[
            DevicePopupMenuButton(
              tooltip: 'Android',
              iconData: Icons.android,
              devices: settings.androidDevices,
              currentIndex: 0,
              backgroundColor: Colors.black,
              iconColor: androidColor,
              onDeviceSelected: (value) {
                controller.onDeviceChanged(DeviceChanged(device: value, orientation: settings.orientation));
              },
            ),
            DevicePopupMenuButton(
              tooltip: 'iOS',
              iconData: FontAwesomeIcons.apple,
              devices: settings.iosDevices,
              currentIndex: 0,
              backgroundColor: Colors.black,
              iconColor: iosColor,
              onDeviceSelected: (value) {
                controller.onDeviceChanged(DeviceChanged(device: value, orientation: settings.orientation));
              },
            ),
            Divider(
              color: settings.dividerColor,
              indent: 4.0,
            ),
            IconButton(
              onPressed: () {
                controller.onDeviceChanged(DeviceChanged(device: device, orientation: Orientation.portrait));
              },
              icon: Icon(Icons.stay_current_portrait, color: portraitColor),
            ),
            IconButton(
              onPressed: () {
                controller.onDeviceChanged(DeviceChanged(device: device, orientation: Orientation.landscape));
              },
              icon: Icon(Icons.stay_current_landscape, color: landscapeColor),
            ),
            Divider(
              color: settings.dividerColor,
              indent: 4.0,
            ),
            if (_showDeviceInfo)
              Tooltip(
                message: device.name,
                child: Container(
                  padding: EdgeInsets.only(left: 8.0),
                  width: 120.0,
                  child: Column(
                    mainAxisSize: MainAxisSize.min,
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: <Widget>[
                      Text(
                        '${device.size.width.round()} px',
                        style: TEXT_STYLE.copyWith(color: overflowX ? Colors.red.shade400 : null),
                      ),
                      Text(
                        '${device.size.height.round()} px',
                        style: TEXT_STYLE.copyWith(color: overflowY ? Colors.red.shade400 : null),
                      ),
                      Padding(
                        padding: EdgeInsets.only(top: 4.0),
                        child: Text(
                          device.name,
                          style: TEXT_STYLE.copyWith(color: settings.accentColor, fontSize: 10.0),
                          maxLines: 1,
                          overflow: TextOverflow.ellipsis,
                          textAlign: TextAlign.start,
                        ),
                      ),
                    ],
                  ),
                ),
              ),
            if (_showDeviceInfo)
              Divider(
                color: settings.dividerColor,
                indent: 4.0,
              ),
            Container(
              child: Padding(
                padding: const EdgeInsets.all(8.0),
                child: IconButton(
                  icon: Icon(
                    settings.brightness == Brightness.light ? Icons.light_mode : Icons.dark_mode,
                    color: settings.accentColor,
                  ),
                  onPressed: () {
                    final newBrightness = controller.brightness == Brightness.light ? Brightness.dark : Brightness.light;
                    controller.onBrightnessChanged(newBrightness);
                  },
                ),
              ),
            ),
            if (settings.showColorSelector)
              Divider(
                color: settings.dividerColor,
                indent: 4.0,
              ),
            if (settings.showColorSelector)
              Container(
                child: Padding(
                  padding: const EdgeInsets.all(8.0),
                  child: IconButton(
                    icon: Icon(
                      Icons.color_lens,
                      color: settings.accentColor,
                    ),
                    onPressed: () async {
                      // final color = await Navigator.of(context).push(MaterialPageRoute(
                      //   builder: (context) => ColorSelectorPage(),
                      // ));
                      final newColor = await showColorSelectorPage(context);
                      controller.onColorChanged(newColor);
                    },
                  ),
                ),
              ),
            Divider(
              color: settings.dividerColor,
              indent: 4.0,
            ),
            Expanded(
              child: _showDeviceSlider
                  ? RotatedBox(
                      quarterTurns: 1,
                      child: Slider(
                        divisions: devices.length - 1,
                        min: 0.0,
                        max: (devices.length - 1).toDouble(),
                        value: devices.indexOf(device).toDouble(),
                        label: device.name,
                        activeColor: settings.accentColor,
                        onChanged: (double device) {
                          final newDevice = devices[device.toInt()];
                          controller.onDeviceChanged(DeviceChanged(device: newDevice, orientation: settings.orientation));
                        },
                      ),
                    )
                  : const SizedBox.expand(),
            ),
            Divider(
              color: settings.dividerColor,
              indent: 4.0,
            ),
            SimulatorLogo(onTap: controller.onLogoClick),
          ],
        ),
      ),
    );
  }
}

==> dotup_flutter_simulator-3.1.2.tar.gz: lib/src/menu/menu_bar_vertical.dart <==
import 'package:dotup_flutter_widgets/dotup_flutter_widgets.dart';
import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';

import '../constants.dart';
import '../device/device_changed.dart';
import '../device/device_descriptor.dart';
import '../device_popup_menu_button.dart';
import '../simulator/simulator_controller.dart';
import '../helper/simulator_logo.dart';

class MenuBarVertical extends StatelessWidget {
  const MenuBarVertical({
    Key? key,
    required this.controller,
  }) : super(key: key);

  final SimulatorController controller;

  @override
  Widget build(BuildContext context) {
    final settings = controller.settings;
    final devices = controller.currentPlatform == TargetPlatform.android ? settings.androidDevices : settings.iosDevices;

    DeviceDescriptor device = controller.currentDevice;

    final portraitColor = controller.orientation == Orientation.portrait ? Colors.white : Colors.white24;
    final landscapeColor = controller.orientation == Orientation.landscape ? Colors.white : Colors.white24;

    final iosColor = controller.currentPlatform == TargetPlatform.iOS ? Colors.white : Colors.white24;
    final androidColor = controller.currentPlatform == TargetPlatform.android ? Colors.white : Colors.white24;
    final _showDeviceInfo = controller.realMediaQuery.size.height > 500;
    final _showDeviceSlider = controller.realMediaQuery.size.height > 700;

    bool overflowX = device.size.width > controller.realMediaQuery.size.width - SETTINGS_HEIGHT;
    bool overflowY = device.size.height > controller.realMediaQuery.size.height;

    return Material(
      child: Container(
        width: SETTINGS_HEIGHT,
        // height: 500,
        color: Colors.grey.shade900,
        padding: EdgeInsets.all(8),
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.stretch,
          mainAxisSize: MainAxisSize.max,
          children: <Widget>[
            DevicePopupMenuButton(
              tooltip: 'Android',
              iconData: Icons.android,
              devices: settings.androidDevices,
              currentIndex: 0,
              backgroundColor: Colors.grey.shade900,
              iconColor: androidColor,
              onDeviceSelected: (value) {
                controller.onDeviceChanged(DeviceChanged(device: value, orientation: settings.orientation));
              },
            ),
            DevicePopupMenuButton(
              tooltip: 'iOS',
              iconData: FontAwesomeIcons.apple,
              devices: settings.iosDevices,
              currentIndex: 0,
              backgroundColor: Colors.grey.shade900,
              iconColor: iosColor,
              onDeviceSelected: (value) {
                controller.onDeviceChanged(DeviceChanged(device: value, orientation: settings.orientation));
              },
            ),
            Divider(
              color: settings.dividerColor,
              indent: 4.0,
            ),
            IconButton(
              onPressed: () {
                controller.onDeviceChanged(DeviceChanged(device: device, orientation: Orientation.portrait));
              },
              icon: Icon(Icons.stay_current_portrait, color: portraitColor),
            ),
            IconButton(
              onPressed: () {
                controller.onDeviceChanged(DeviceChanged(device: device, orientation: Orientation.landscape));
              },
              icon: Icon(Icons.stay_current_landscape, color: landscapeColor),
            ),
            Divider(
              color: settings.dividerColor,
              indent: 4.0,
            ),
            if (_showDeviceInfo)
              Tooltip(
                message: device.name,
                child: Container(
                  padding: EdgeInsets.only(left: 8.0),
                  width: 120.0,
                  child: Column(
                    mainAxisSize: MainAxisSize.min,
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: <Widget>[
                      Text(
                        '${device.size.width.round()} px',
                        style: TEXT_STYLE.copyWith(color: overflowX ? Colors.red.shade400 : null),
                      ),
                      Text(
                        '${device.size.height.round()} px',
                        style: TEXT_STYLE.copyWith(color: overflowY ? Colors.red.shade400 : null),
                      ),
                      Padding(
                        padding: EdgeInsets.only(top: 4.0),
                        child: Text(
                          device.name,
                          style: TEXT_STYLE.copyWith(color: settings.accentColor, fontSize: 10.0),
                          maxLines: 1,
                          overflow: TextOverflow.ellipsis,
                          textAlign: TextAlign.start,
                        ),
                      ),
                    ],
                  ),
                ),
              ),
            if (_showDeviceInfo)
              Divider(
                color: settings.dividerColor,
                indent: 4.0,
              ),
            Container(
              child: Padding(
                padding: const EdgeInsets.all(8.0),
                child: IconButton(
                  icon: Icon(
                    settings.brightness == Brightness.light ? Icons.light_mode : Icons.dark_mode,
                    color: settings.accentColor,
                  ),
                  onPressed: () {
                    final newBrightness = controller.brightness == Brightness.light ? Brightness.dark : Brightness.light;
                    controller.onBrightnessChanged(newBrightness);
                  },
                ),
              ),
            ),
            if (settings.showColorSelector)
              Divider(
                color: settings.dividerColor,
                indent: 4.0,
              ),
            if (settings.showColorSelector)
              Container(
                child: Padding(
                  padding: const EdgeInsets.all(8.0),
                  child: IconButton(
                    icon: Icon(
                      Icons.color_lens,
                      color: settings.accentColor,
                    ),
                    onPressed: () async {
                      // final color = await Navigator.of(context).push(MaterialPageRoute(
                      //   builder: (context) => ColorSelectorPage(),
                      // ));
                      final newColor = await showColorSelectorPage(context);
                      controller.onColorChanged(newColor);
                    },
                  ),
                ),
              ),
            Divider(
              color: settings.dividerColor,
              indent: 4.0,
            ),
            Expanded(
              child: _showDeviceSlider
                  ? RotatedBox(
                      quarterTurns: 1,
                      child: Slider(
                        divisions: devices.length - 1,
                        min: 0.0,
                        max: (devices.length - 1).toDouble(),
                        value: devices.indexOf(device).toDouble(),
                        label: device.name,
                        activeColor: settings.accentColor,
                        onChanged: (double device) {
                          final newDevice = devices[device.toInt()];
                          controller.onDeviceChanged(DeviceChanged(device: newDevice, orientation: settings.orientation));
                        },
                      ),
                    )
                  : const SizedBox.expand(),
            ),
            Divider(
              color: settings.dividerColor,
              indent: 4.0,
            ),
            SimulatorLogo(onTap: controller.onLogoClick),
          ],
        ),
      ),
    );
  }
}
